"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk = tslib_1.__importStar(require("chalk"));
const fs = tslib_1.__importStar(require("fs"));
const glob_1 = tslib_1.__importDefault(require("glob"));
const minimatch_1 = tslib_1.__importDefault(require("minimatch"));
const path = tslib_1.__importStar(require("path"));
const util = tslib_1.__importStar(require("util"));
class CommandModule {
    static targetFileFilter({ filenames, option, logger, }) {
        const targetExts = option.targetExts.map((ext) => (ext.startsWith('.') ? ext : `.${ext}`));
        try {
            const filteredFiles = filenames
                .filter((filename) => targetExts.indexOf(path.extname(filename)) >= 0)
                .filter((filename) => {
                return !option.excludes.reduce((result, exclude) => {
                    return result || path.dirname(filename).indexOf(exclude) >= 0;
                }, false);
            })
                .filter((filename) => !filename.endsWith('.d.ts'))
                .filter((filename) => {
                return !option.fileExcludePatterns.reduce((result, excludePattern) => {
                    if (!glob_1.default.hasMagic(excludePattern, option.globOptions)) {
                        return result || minimatch_1.default(filename, `*${excludePattern}*`);
                    }
                    return result || minimatch_1.default(filename, excludePattern);
                }, false);
            })
                .filter((filename) => {
                return !option.targetExts
                    .map((ext) => `index.${ext}`)
                    .reduce((result, indexFile) => {
                    return result || filename.indexOf(indexFile) >= 0;
                }, false);
            })
                .filter((filename) => {
                return filename !== '.';
            });
            return filteredFiles;
        }
        catch (err) {
            logger.error(chalk.default.redBright('Error occured: ', err));
            return [];
        }
    }
    static getDefaultOption(cwd) {
        return {
            addNewline: true,
            excludes: ['@types', 'typings', '__test__', '__tests__', 'node_modules'],
            fileExcludePatterns: [],
            fileFirst: false,
            globOptions: {
                cwd: cwd || process.cwd(),
                dot: true,
                nonull: true,
            },
            includeCWD: true,
            quote: "'",
            targetExts: ['ts', 'tsx'],
            useSemicolon: true,
            useTimestamp: false,
            verbose: false,
            withoutComment: false,
        };
    }
}
CommandModule.promisify = {
    glob: util.promisify(glob_1.default),
    readDir: util.promisify(fs.readdir),
    stat: util.promisify(fs.stat),
    unlink: util.promisify(fs.unlink),
    writeFile: util.promisify(fs.writeFile),
};
exports.CommandModule = CommandModule;
//# sourceMappingURL=CommandModule.js.map