"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const dayjs = tslib_1.__importStar(require("dayjs"));
const debug_1 = tslib_1.__importDefault(require("debug"));
const fs = tslib_1.__importStar(require("fs"));
const json5 = tslib_1.__importStar(require("json5"));
const path = tslib_1.__importStar(require("path"));
const CreateTsIndexOption_1 = require("../options/CreateTsIndexOption");
const ctircLoader_1 = require("../options/ctircLoader");
const CTILogger_1 = require("../tools/CTILogger");
const CTIUtility_1 = require("../tools/CTIUtility");
const log = debug_1.default('cti:InitCommandModule');
class InitCommandModule {
    do(cliCwd, passed) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const cwd = CTIUtility_1.isNotEmpty(passed.globOptions) && CTIUtility_1.isNotEmpty(passed.globOptions.cwd)
                ? passed.globOptions.cwd
                : process.cwd();
            const { readedFrom, option } = ctircLoader_1.ctircLoader({
                cwd: cliCwd,
                fromCliOption: passed,
                inputDir: null,
            });
            log('Option: ', option.useTimestamp);
            const logger = new CTILogger_1.CTILogger(option.verbose);
            logger.log('configuration from: ', readedFrom === '' ? 'default' : readedFrom);
            try {
                const defaultOption = CreateTsIndexOption_1.getDefailtICreateTsIndexOption(cwd);
                const stringified = json5.stringify(defaultOption, null, 2);
                const headContent = (() => {
                    if (option.useTimestamp) {
                        return `// created from ${option.quote}create-ts-index${option.quote} ${dayjs.default().format('YYYY-MM-DD HH:mm')}`;
                    }
                    return `// created from ${option.quote}create-ts-index${option.quote}`;
                })();
                const addNewline = (() => {
                    if (option.addNewline) {
                        return '\n';
                    }
                    return '';
                })();
                yield new Promise((resolve, reject) => {
                    fs.writeFile(path.join(cwd, '.ctirc'), `${headContent}\n\n${stringified}${addNewline}`, (err) => {
                        if (CTIUtility_1.isNotEmpty(err)) {
                            return reject(err);
                        }
                        logger.flog(chalk_1.default.green(`.ctirc create succeeded: ${option.globOptions.cwd}`));
                        return resolve();
                    });
                });
            }
            catch (err) {
                logger.error(chalk_1.default.red('indexWriter: ', err.message));
                logger.error(chalk_1.default.red('indexWriter: ', err.stack));
            }
        });
    }
    write(_args) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            throw new Error('Not implements');
        });
    }
}
exports.InitCommandModule = InitCommandModule;
//# sourceMappingURL=InitCommandModule.js.map