#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk = tslib_1.__importStar(require("chalk"));
const debug_1 = tslib_1.__importDefault(require("debug"));
const fs = tslib_1.__importStar(require("fs"));
const CleanCommandModule_1 = require("./commands/CleanCommandModule");
const CreateCommandModule_1 = require("./commands/CreateCommandModule");
const EntrypointCommandModule_1 = require("./commands/EntrypointCommandModule");
const InitCommandModule_1 = require("./commands/InitCommandModule");
const EN_CLIOPTION_1 = require("./EN_CLIOPTION");
const CreateTsIndexOption_1 = require("./options/CreateTsIndexOption");
const CTIUtility_1 = require("./tools/CTIUtility");
const yargs = require("yargs");
const log = debug_1.default('cti:cti-cli');
const version = '1.10.2';
const optionMap = {
    [EN_CLIOPTION_1.EN_CLI_OPTION.FILEFIRST]: {
        alias: 'f',
        describe: 'export list create filefirst, no option false, option true',
        type: 'boolean',
    },
    [EN_CLIOPTION_1.EN_CLI_OPTION.ADD_NEWLINE]: {
        alias: 'n',
        describe: 'deside add newline file ending. no option true, option false',
        type: 'boolean',
    },
    [EN_CLIOPTION_1.EN_CLI_OPTION.USE_SEMICOLON]: {
        alias: 's',
        describe: 'deside use semicolon line ending. no option true, option false',
        type: 'boolean',
    },
    [EN_CLIOPTION_1.EN_CLI_OPTION.INCLUDE_CWD]: {
        alias: 'c',
        describe: 'deside include cwd directory in task. no option true, option false',
        type: 'boolean',
    },
    [EN_CLIOPTION_1.EN_CLI_OPTION.USE_TIMESTAMP]: {
        alias: 't',
        describe: `deside use timestamp(YYYY-MM-DD HH:mm) top line comment. \nno option false, option true`,
        type: 'boolean',
    },
    [EN_CLIOPTION_1.EN_CLI_OPTION.EXCLUDES]: {
        alias: 'e',
        array: true,
        describe: `pass exclude directory. default exclude directory is ['@types', 'typings', '__test__', '__tests__']`,
        type: 'string',
    },
    [EN_CLIOPTION_1.EN_CLI_OPTION.FILE_EXCLUDES]: {
        alias: 'i',
        array: true,
        describe: 'pass exclude pattern of filename. default exclude directory is "[]"',
        type: 'string',
    },
    [EN_CLIOPTION_1.EN_CLI_OPTION.TARGET_EXTS]: {
        alias: 'x',
        array: true,
        describe: `pass include extname. default extname is ["ts", "tsx"]. extname \npass without dot charactor.`,
        type: 'string',
    },
    [EN_CLIOPTION_1.EN_CLI_OPTION.WITHOUT_COMMENT]: {
        alias: 'w',
        describe: 'remove comment from created output',
        type: 'boolean',
    },
    [EN_CLIOPTION_1.EN_CLI_OPTION.VERBOSE]: {
        alias: 'v',
        describe: 'verbose logging message. to option false, option true',
        type: 'boolean',
    },
    [EN_CLIOPTION_1.EN_CLI_OPTION.QUOTE]: {
        alias: 'q',
        describe: "deside quote character. default quote character is '",
        type: 'string',
    },
};
function createCommandOptionBuilder(args) {
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.FILEFIRST, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.FILEFIRST]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.ADD_NEWLINE, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.ADD_NEWLINE]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.USE_SEMICOLON, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.USE_SEMICOLON]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.INCLUDE_CWD, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.INCLUDE_CWD]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.USE_TIMESTAMP, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.USE_TIMESTAMP]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.EXCLUDES, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.EXCLUDES]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.FILE_EXCLUDES, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.FILE_EXCLUDES]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.TARGET_EXTS, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.TARGET_EXTS]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.VERBOSE, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.VERBOSE]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.WITHOUT_COMMENT, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.WITHOUT_COMMENT]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.QUOTE, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.QUOTE]);
    return args;
}
function createCommandActor(args) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const cwds = args.cwds;
        const cliCwd = process.cwd();
        if (!cwds) {
            console.log(chalk.default.magenta('Enter working directory, '));
            console.log(chalk.default.red('cti [working directory]'));
            process.exit(1);
        }
        if (typeof cwds === 'string') {
            const createCommand = new CreateCommandModule_1.CreateCommandModule();
            const options = CreateTsIndexOption_1.createOptionBuilder(args, cwds);
            return createCommand.do(cliCwd, options);
        }
        if (typeof cwds !== 'string' && Array.isArray(cwds)) {
            return Promise.all(cwds
                .filter((cwd) => fs.existsSync(cwd))
                .map((cwd) => {
                const createCommand = new CreateCommandModule_1.CreateCommandModule();
                const options = CreateTsIndexOption_1.createOptionBuilder(args, cwd);
                return createCommand.do(cliCwd, options);
            }));
        }
    });
}
yargs
    .command('$0 [cwds...]', 'create index.ts file in working directory', createCommandOptionBuilder, createCommandActor)
    .command('create [cwds...]', 'create index.ts file in working directory', createCommandOptionBuilder, createCommandActor)
    .command('entrypoint [cwds...]', 'create entrypoint.ts file in working directory', (args) => {
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.ADD_NEWLINE, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.ADD_NEWLINE]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.USE_SEMICOLON, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.USE_SEMICOLON]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.INCLUDE_CWD, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.INCLUDE_CWD]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.USE_TIMESTAMP, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.USE_TIMESTAMP]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.EXCLUDES, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.EXCLUDES]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.FILE_EXCLUDES, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.FILE_EXCLUDES]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.TARGET_EXTS, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.TARGET_EXTS]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.VERBOSE, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.VERBOSE]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.WITHOUT_COMMENT, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.WITHOUT_COMMENT]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.QUOTE, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.QUOTE]);
    return args;
}, (args) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const cwds = args.cwds;
    const cliCwd = process.cwd();
    if (!cwds) {
        console.log(chalk.default.magenta('Enter working directory, '));
        console.log(chalk.default.red('cti [working directory]'));
        process.exit(1);
    }
    if (typeof cwds === 'string') {
        const entrypointCommand = new EntrypointCommandModule_1.EntrypointCommandModule();
        const options = CreateTsIndexOption_1.entrypointOptionBuilder(args, cwds);
        return entrypointCommand.do(cliCwd, options);
    }
    if (typeof cwds !== 'string' && Array.isArray(cwds)) {
        return Promise.all(cwds
            .filter((cwd) => fs.existsSync(cwd))
            .map((cwd) => {
            const entrypointCommand = new EntrypointCommandModule_1.EntrypointCommandModule();
            const options = CreateTsIndexOption_1.entrypointOptionBuilder(args, cwd);
            return entrypointCommand.do(cliCwd, options);
        }));
    }
}))
    .command('init [cwds...]', 'create .ctirc file in working directory', (args) => {
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.ADD_NEWLINE, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.ADD_NEWLINE]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.USE_TIMESTAMP, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.USE_TIMESTAMP]);
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.VERBOSE, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.VERBOSE]);
    return args;
}, (args) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const cwds = CTIUtility_1.isNotEmpty(args.cwds) ? args.cwds : [process.cwd()];
    const cliCwd = process.cwd();
    log('init command start, ', cwds);
    if (typeof cwds === 'string') {
        const initCommandModule = new InitCommandModule_1.InitCommandModule();
        const options = CreateTsIndexOption_1.initOptionBuilder(args, cwds);
        return initCommandModule.do(cliCwd, options);
    }
    if (typeof cwds !== 'string' && Array.isArray(cwds)) {
        return Promise.all(cwds
            .filter((cwd) => fs.existsSync(cwd))
            .map((cwd) => {
            const initCommandModule = new InitCommandModule_1.InitCommandModule();
            const options = CreateTsIndexOption_1.initOptionBuilder(args, cwd);
            return initCommandModule.do(cliCwd, options);
        }));
    }
}))
    .command('clean [cwds...]', 'clean index.ts or entrypoint.ts file in working directory', (args) => {
    args.option(EN_CLIOPTION_1.EN_CLI_OPTION.VERBOSE, optionMap[EN_CLIOPTION_1.EN_CLI_OPTION.VERBOSE]);
    return args;
}, (args) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const cwds = args['cwds'];
    const cliCwd = process.cwd();
    if (!cwds) {
        console.log(chalk.default.magenta('Enter working directory, '));
        console.log(chalk.default.red('cti [working directory]'));
        process.exit(1);
    }
    if (typeof cwds === 'string') {
        const cleanCommand = new CleanCommandModule_1.CleanCommandModule();
        const options = CreateTsIndexOption_1.cleanOptionBuilder(args, cwds);
        yield cleanCommand.do(cliCwd, options);
    }
    if (typeof cwds !== 'string' && Array.isArray(cwds)) {
        return Promise.all(cwds
            .filter((cwd) => fs.existsSync(cwd))
            .map((cwd) => {
            const cleanCommand = new CleanCommandModule_1.CleanCommandModule();
            const options = CreateTsIndexOption_1.cleanOptionBuilder(args, cwd);
            return cleanCommand.do(cliCwd, options);
        }));
    }
    return true;
}))
    .version(version, 'version', 'display version information')
    .help().argv;
//# sourceMappingURL=cti.js.map